==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mainmenu/translations/mainmenu_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>RazorMainMenu</name>
    <message>
        <location filename="../razormainmenu.cpp" line="170"/>
        <source>Leave</source>
        <translation>Opustit</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="14"/>
        <source>Razor Main Menu settings</source>
        <translation>Nastavení hlavní nabídky</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Ukázat text</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="45"/>
        <source>Button text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="65"/>
        <location filename="../razormainmenuconfiguration.ui" line="71"/>
        <source>Menu file</source>
        <translation>Soubor s nabídkou</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="85"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="83"/>
        <source>Choose menu file</source>
        <translation>Vybrat soubor s nabídkou</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="83"/>
        <source>Menu files (*.menu)</source>
        <translation>Soubory s nabídkami (*.menu)</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mainmenu/translations/mainmenu_cs_CZ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Opustit</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Nastavení hlavní nabídky</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Ukázat text</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>Soubor s nabídkou</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation>Klávesová zkratka</translation>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation>Klepněte na tlačítko pro nahrání klávesové zkratky:</translation>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Vybrat soubor s nabídkou</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Soubory s nabídkami (*.menu)</translation>
    </message>
</context>
</TS>
